@@ -14,6 +14,8 @@
 
 package org.eclipse.jdt.compiler.apt.tests.processors.elements;
 
+import java.io.IOException;
+import java.io.Writer;
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 import java.util.ArrayList;
@@ -23,6 +25,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 
+import javax.annotation.processing.Filer;
 import javax.annotation.processing.Messager;
 import javax.annotation.processing.ProcessingEnvironment;
 import javax.annotation.processing.RoundEnvironment;
@@ -48,9 +51,11 @@ import javax.lang.model.type.DeclaredType;
 import javax.lang.model.type.NoType;
 import javax.lang.model.type.TypeKind;
 import javax.lang.model.type.TypeMirror;
+import javax.tools.JavaFileObject;
 
 import org.eclipse.jdt.compiler.apt.tests.processors.base.BaseProcessor;
 import org.eclipse.jdt.compiler.apt.tests.processors.util.TestDirectiveVisitor;
+import org.eclipse.jdt.internal.compiler.impl.CompilerOptions;
 
 /**
  * A processor that explores the java 9 specific elements and validates the lambda and 
@@ -63,26 +68,23 @@ public class Java9ElementProcessor extends BaseProcessor {
 	boolean reportSuccessAlready = true;
 	RoundEnvironment roundEnv = null;
 	Messager _messager = null;
+	boolean isJre12;
 	boolean isJre11;
 	boolean isJre10;
+	int roundNo = 0;
 	@Override
 	public synchronized void init(ProcessingEnvironment processingEnv) {
 		super.init(processingEnv);
 		_typeUtils = processingEnv.getTypeUtils();
 		_messager = processingEnv.getMessager();
-		try {
-			SourceVersion.valueOf("RELEASE_11");
+		String property = System.getProperty("java.specification.version");
+		if (property.equals(CompilerOptions.VERSION_10)) {
 			this.isJre10 = true;
+		} else if (property.equals(CompilerOptions.VERSION_11)) {
 			this.isJre11 = true;
-		} catch(IllegalArgumentException iae) {
-		}
-		if (!this.isJre11) {
-			try {
-				SourceVersion.valueOf("RELEASE_10");
-				this.isJre10 = true;
-			} catch(IllegalArgumentException iae) {
-			}
-		}
+		} else if (property.equals(CompilerOptions.VERSION_12)) {
+			this.isJre12 = true;
+		} 
 	}
 	// Always return false from this processor, because it supports "*".
 	// The return value does not signify success or failure!
@@ -415,7 +417,7 @@ public class Java9ElementProcessor extends BaseProcessor {
 		assertNotNull("java.base module null", base);
 		List<? extends Directive> directives = base.getDirectives();
 		List<Directive> filterDirective = filterDirective(directives, DirectiveKind.EXPORTS);
-		assertEquals("incorrect no of exports", this.isJre11 ? 108 : (this.isJre10 ? 102 : 108) , filterDirective.size());
+		assertEquals("incorrect no of exports", this.isJre11 ? 107 : (this.isJre10 ? 102 : 108) , filterDirective.size());
 		ExportsDirective pack = null;
 		for (Directive directive : filterDirective) {
 			ModuleElement.ExportsDirective exports = (ExportsDirective) directive;
@@ -476,7 +478,7 @@ public class Java9ElementProcessor extends BaseProcessor {
 		assertNotNull("java.base module null", base);
 		List<? extends Directive> directives = base.getDirectives();
 		List<Directive> filterDirective = filterDirective(directives, DirectiveKind.USES);
-		assertEquals("incorrect no of uses", 34 , filterDirective.size());
+		assertEquals("incorrect no of uses", (this.isJre11 || this.isJre12) ? 33 : 34, filterDirective.size());
 	}
 	/*
 	 * Test java.base module can be loaded and verify its 'provides' attributes
@@ -530,7 +532,7 @@ public class Java9ElementProcessor extends BaseProcessor {
 		assertNotNull("java.sql module null", base);
 		List<? extends Directive> directives = base.getDirectives();
 		List<Directive> filterDirective = filterDirective(directives, DirectiveKind.REQUIRES);
-		assertEquals("Incorrect no of requires", this.isJre11 ? 4 : 3, filterDirective.size());
+		assertEquals("Incorrect no of requires", (this.isJre11 || this.isJre12) ? 4 : 3, filterDirective.size());
 		RequiresDirective req = null;
 		for (Directive directive : filterDirective) {
 			if (((RequiresDirective) directive).getDependency().getQualifiedName().toString().equals("java.logging")) {
@@ -824,6 +826,53 @@ public class Java9ElementProcessor extends BaseProcessor {
 		TypeElement typeEl = (TypeElement) declaredType.asElement();
 		verifyAnnotations(typeEl, new String[] {"@targets.model9.q.FooBarAnnotation()"});
 	}
+	public boolean testBug535819() {
+		if (++roundNo == 1) {
+			this.reportSuccessAlready = false;
+			try {
+				TypeElement annotatedType = _elementUtils.getTypeElement("targets.bug535819.Entity1");
+				System.out.println(annotatedType);
+				Filer filer = processingEnv.getFiler();
+				JavaFileObject jfo = filer.createSourceFile("targets.bug535819.query.QEntity1", annotatedType);
+				Writer writer = jfo.openWriter();
+				writer.write("package targets.bug535819.query;\n" + 
+						"  \n" + 
+						"import targets.bug535819.Entity1;\n" + 
+						"public class QEntity1 {\n" + 
+						"  private static final QEntity1 _alias = new QEntity1(true);\n" + 
+						"  public QEntity1() {\n" + 
+						"    super(Entity1.class);\n" + 
+						"  }\n" + 
+						"  private QEntity1(boolean dummy) {\n" + 
+						"    super(dummy);\n" + 
+						"  }\n" + 
+						"  public static class Alias {\n" + 
+						"  }\n" + 
+						"}");
+				writer.close();
+				
+				jfo = filer.createSourceFile("targets.bug535819.assoc.QAssocEntity1", annotatedType);
+				writer = jfo.openWriter();
+				writer.write("package targets.bug535819.query.assoc;\n" + 
+						"  \n" + 
+						"import targets.bug535819.Entity1;\n" + 
+						"import targets.bug535819.query.QEntity1;\n" + 
+						"public class QAssocEntity1<R>  {\n" + 
+						"  public QAssocEntity1(String name, R root) {\n" + 
+						"    super(name, root);\n" + 
+						"  }\n" + 
+						"}\n" + 
+						"");
+				writer.close();	
+			} catch (IOException e) {
+				e.printStackTrace();
+			}
+			//System.setProperty(this.getClass().getName(), "Processor did not fully do the job");
+		} else if (roundNo == 2){
+			this.reportSuccessAlready = true;
+		}
+		return false;
+	}
 	private void validateModifiers(ExecutableElement method, Modifier[] expected) {
 		Set<Modifier> modifiers = method.getModifiers();
 		List<Modifier> list = new ArrayList<>(modifiers);
@@ -853,7 +902,7 @@ public class Java9ElementProcessor extends BaseProcessor {
 	public void reportError(String msg) {
 		throw new AssertionFailedError(msg);
 	}
-	private String getExceptionStackTrace(Throwable t) {
+	protected String getExceptionStackTrace(Throwable t) {
 		StringBuffer buf = new StringBuffer(t.getMessage());
 		StackTraceElement[] traces = t.getStackTrace();
 		for (int i = 0; i < traces.length; i++) {
