@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -14,6 +14,8 @@
  *								bug 376590 - Private fields with @Inject are ignored by unused field validation
  *     Ulrich Grave <ulrich.grave@gmx.de> - Contributions for
  *                              bug 386692 - Missing "unused" warning on "autowired" fields
+ *     Pierre-Yves B. <pyvesdev@gmail.com> - Contribution for
+ *                              bug 542520 - [JUnit 5] Warning The method xxx from the type X is never used locally is shown when using MethodSource
  *******************************************************************************/
 package org.eclipse.jdt.core.tests.compiler.regression;
 
@@ -68,6 +70,21 @@ public class AbstractComparableTest extends AbstractRegressionTest {
 		"\n" +
 		"}";
 
+	protected static final String JUNIT_METHODSOURCE_NAME = "org/junit/jupiter/params/provider/MethodSource.java";
+	protected static final String JUNIT_METHODSOURCE_CONTENT =
+	    "package org.junit.jupiter.params.provider;\n" +
+	    "import java.lang.annotation.ElementType;\n" +
+	    "import java.lang.annotation.Retention;\n" +
+	    "import java.lang.annotation.RetentionPolicy;\n" +
+	    "import java.lang.annotation.Target;\n" +
+	    "@Target({ElementType.ANNOTATION_TYPE, ElementType.METHOD})\n" +
+	    "@Retention(RetentionPolicy.RUNTIME)\n" +
+	    "public @interface MethodSource {\n" +
+	    "\n" +
+	    "	String[] value() default \"\";\n" +
+	    "\n" +
+	    "}";
+
 	public static Test buildComparableTestSuite(Class evaluationTestClass) {
 		Test suite = buildMinimalComplianceTestSuite(evaluationTestClass, F_1_5);
 		TESTS_COUNTERS.put(evaluationTestClass.getName(), Integer.valueOf(suite.countTestCases()));
@@ -93,6 +110,29 @@ public class AbstractComparableTest extends AbstractRegressionTest {
 	}
 	
 	protected String intersection(String... types) {
+		// From JDK 12, Comparable gets two new super interfaces, namely Constable and ConstantDesc.
+		// The idea is to append Comparable with &Constable&ConstantDesc automatically.
+		if (isJRE12Plus) {
+			int index = -1;
+			for(int i = 0; i < types.length; i++) {
+				if (types[i].startsWith("Comparable") && !types[i].endsWith("ConstantDesc")) {
+					if ((types.length <= i+1) || !types[i+1].startsWith("CharSequence")) {
+						index = i;
+						break;
+					}
+				}
+			}
+			if (index >= 0) {
+				index++;
+				String[] temp = new String[types.length + 2];
+				System.arraycopy(types, 0, temp, 0, index);
+				temp[index] = "Constable";
+				temp[index+1] = "ConstantDesc";
+				if (index < types.length)
+ 					System.arraycopy(types, index, temp, index+2, types.length - index);
+				types = temp;
+			}
+		}
 		if (this.complianceLevel >= ClassFileConstants.JDK1_8)
 			return String.join(" & ", types);
 		return String.join("&", types);
