@@ -1,10 +1,13 @@
 /*******************************************************************************
- * Copyright (c) 2013, 2017 Jesper Steen Moeller and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * Copyright (c) 2013, 2018 Jesper Steen Moeller and others.
+ *
+ * This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
- * 
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
+ *
  * Contributors:
  *     Jesper Steen Moeller - initial API and implementation
  *			bug 527554 - [18.3] Compiler support for JEP 286 Local-Variable Type
@@ -19,6 +22,7 @@ import java.util.Map;
 import junit.framework.Test;
 
 import org.eclipse.jdt.core.ToolFactory;
+import org.eclipse.jdt.core.tests.util.AbstractCompilerTest;
 import org.eclipse.jdt.core.tests.util.Util;
 import org.eclipse.jdt.core.util.ClassFileBytesDisassembler;
 import org.eclipse.jdt.internal.compiler.classfmt.ClassFileConstants;
@@ -35,9 +39,7 @@ public class MethodParametersAttributeTest extends AbstractRegressionTest {
 	// No need for a tearDown()
 	protected void setUp() throws Exception {
 		super.setUp();
-		this.versionString = (this.complianceLevel < ClassFileConstants.JDK9)
-				? "version 1.8 : 52.0"
-				: (this.complianceLevel < ClassFileConstants.JDK10 ? "version 9 : 53.0" : "version 10 : 54.0");
+		this.versionString = AbstractCompilerTest.getVersionString(this.complianceLevel);
 	}
 	@SuppressWarnings("rawtypes")
 	public static Class testClass() {
@@ -385,7 +387,15 @@ public class MethodParametersAttributeTest extends AbstractRegressionTest {
 				classFileBytes,
 				"\n",
 				ClassFileBytesDisassembler.DETAILED);
-	
+
+		String nestMembers = "";
+		CompilerOptions options = new CompilerOptions(getCompilerOptions());
+		if (options.complianceLevel >= ClassFileConstants.JDK11) {
+			nestMembers = "\n" + 
+					"Nest Members:\n" + 
+					"   #20 ParameterNames$1,\n" + 
+					"   #29 ParameterNames$1Local\n";
+		}
 		String expectedOutput =
 				"// Compiled from ParameterNames.java (" + this.versionString + ", super bit)\n" + 
 				"public class ParameterNames {\n" + 
@@ -450,7 +460,8 @@ public class MethodParametersAttributeTest extends AbstractRegressionTest {
 				"    [inner class info: #20 ParameterNames$1, outer class info: #0\n" + 
 				"     inner name: #0, accessflags: 0 default],\n" + 
 				"    [inner class info: #29 ParameterNames$1Local, outer class info: #0\n" + 
-				"     inner name: #41 Local, accessflags: 0 default]\n" + 
+				"     inner name: #41 Local, accessflags: 0 default]\n" +
+				nestMembers +
 				"}";
 
 		assertSubstring(actualOutput, expectedOutput);
@@ -472,6 +483,12 @@ public class MethodParametersAttributeTest extends AbstractRegressionTest {
 				"\n",
 				ClassFileBytesDisassembler.DETAILED);
 
+		String nestHost = "";
+		CompilerOptions options = new CompilerOptions(getCompilerOptions());
+		if (options.complianceLevel >= ClassFileConstants.JDK11) {
+			nestHost = "\n" +
+		               "Nest Host: #36 ParameterNames\n";
+		}
 		String expectedOutput =
 			"// Compiled from ParameterNames.java (" + this.versionString + ", super bit)\n" + 
 			"// Signature: Ljava/lang/Object;Ljava/util/concurrent/Callable<Ljava/lang/String;>;\n" + 
@@ -522,7 +539,8 @@ public class MethodParametersAttributeTest extends AbstractRegressionTest {
 			"  Inner classes:\n" + 
 			"    [inner class info: #1 ParameterNames$1, outer class info: #0\n" + 
 			"     inner name: #0, accessflags: 0 default]\n" + 
-			"  Enclosing Method: #36  #38 ParameterNames.makeInnerWithCapture(Ljava/lang/String;Ljava/lang/String;)Ljava/util/concurrent/Callable;\n" + 
+			"  Enclosing Method: #36  #38 ParameterNames.makeInnerWithCapture(Ljava/lang/String;Ljava/lang/String;)Ljava/util/concurrent/Callable;\n" +
+			nestHost +
 			"}"	;
 
 		assertSubstring(actualOutput, expectedOutput);
