@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2014 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -253,7 +253,9 @@ public class ExplicitConstructorCall extends Statement implements Invocation {
 			MethodBinding codegenBinding = this.binding.original();
 
 			// perform some emulation work in case there is some and we are inside a local type only
-			if (this.binding.isPrivate() && this.accessMode != ExplicitConstructorCall.This) {
+			if (this.binding.isPrivate() &&
+					!currentScope.enclosingSourceType().isNestmateOf(this.binding.declaringClass) &&
+					this.accessMode != ExplicitConstructorCall.This) {
 				ReferenceBinding declaringClass = codegenBinding.declaringClass;
 				// from 1.4 on, local type constructor can lose their private flag to ease emulation
 				if ((declaringClass.tagBits & TagBits.IsLocalType) != 0 && currentScope.compilerOptions().complianceLevel >= ClassFileConstants.JDK1_4) {
@@ -444,7 +446,7 @@ public class ExplicitConstructorCall extends Statement implements Invocation {
 						scope.problemReporter().missingTypeInConstructor(this, this.binding);
 					}
 				}
-				if (isMethodUseDeprecated(this.binding, scope, this.accessMode != ExplicitConstructorCall.ImplicitSuper)) {
+				if (isMethodUseDeprecated(this.binding, scope, this.accessMode != ExplicitConstructorCall.ImplicitSuper, this)) {
 					scope.problemReporter().deprecatedMethod(this.binding, this);
 				}
 				if (checkInvocationArguments(scope, null, receiverType, this.binding, this.arguments, argumentTypes, argsContainCast, this)) {
