@@ -11,6 +11,8 @@
 package java.util;
 
 
-public interface Set<U> extends Collection<U> {
-	public Iterator<U> iterator();
+public class Set {
+	public Iterator iterator() {
+		return null;
+	}
 }
